@@ -26,7 +26,8 @@
 
 #undef GTK_DISABLE_DEPRECATED
 
-#include <config.h>
+#include "config.h"
+
 #include "gtklabel.h"
 #include "gtkeventbox.h"
 #include "gtkpixmap.h"
@@ -37,6 +38,7 @@
 #include "gtktree.h"
 #include "gtktreeitem.h"
 #include "gtkintl.h"
+
 #include "gtkalias.h"
 
 #include "tree_plus.xpm"
@@ -185,7 +187,7 @@ gtk_tree_item_subtree_button_click (GtkWidget *widget)
   g_return_val_if_fail (GTK_IS_EVENT_BOX (widget), FALSE);
   
   item = (GtkTreeItem*) gtk_object_get_user_data (GTK_OBJECT (widget));
-  if (!GTK_WIDGET_IS_SENSITIVE (item))
+  if (!gtk_widget_is_sensitive (GTK_WIDGET (item)))
     return FALSE;
   
   if (item->expanded)
@@ -202,7 +204,7 @@ gtk_tree_item_subtree_button_changed_state (GtkWidget *widget)
 {
   g_return_if_fail (GTK_IS_EVENT_BOX (widget));
   
-  if (GTK_WIDGET_VISIBLE (widget))
+  if (gtk_widget_get_visible (widget))
     {
       
       if (widget->state == GTK_STATE_NORMAL)
@@ -210,7 +212,7 @@ gtk_tree_item_subtree_button_changed_state (GtkWidget *widget)
       else
 	gdk_window_set_background (widget->window, &widget->style->bg[widget->state]);
       
-      if (GTK_WIDGET_DRAWABLE (widget))
+      if (gtk_widget_is_drawable (widget))
 	gdk_window_clear_area (widget->window, 0, 0, 
 			       widget->allocation.width, widget->allocation.height);
     }
@@ -220,24 +222,22 @@ static void
 gtk_tree_item_init (GtkTreeItem *tree_item)
 {
   GtkWidget *eventbox, *pixmapwid;
-  
-  g_return_if_fail (GTK_IS_TREE_ITEM (tree_item));
 
   tree_item->expanded = FALSE;
   tree_item->subtree = NULL;
-  GTK_WIDGET_SET_FLAGS (tree_item, GTK_CAN_FOCUS);
+  gtk_widget_set_can_focus (GTK_WIDGET (tree_item), TRUE);
   
   /* create an event box containing one pixmaps */
   eventbox = gtk_event_box_new();
   gtk_widget_set_events (eventbox, GDK_BUTTON_PRESS_MASK);
-  gtk_signal_connect(GTK_OBJECT(eventbox), "state_changed",
-		     (GtkSignalFunc)gtk_tree_item_subtree_button_changed_state, 
+  gtk_signal_connect(GTK_OBJECT(eventbox), "state-changed",
+		     G_CALLBACK (gtk_tree_item_subtree_button_changed_state),
 		     (gpointer)NULL);
   gtk_signal_connect(GTK_OBJECT(eventbox), "realize",
-		     (GtkSignalFunc)gtk_tree_item_subtree_button_changed_state, 
+		     G_CALLBACK (gtk_tree_item_subtree_button_changed_state),
 		     (gpointer)NULL);
-  gtk_signal_connect(GTK_OBJECT(eventbox), "button_press_event",
-		     (GtkSignalFunc)gtk_tree_item_subtree_button_click,
+  gtk_signal_connect(GTK_OBJECT(eventbox), "button-press-event",
+		     G_CALLBACK (gtk_tree_item_subtree_button_click),
 		     (gpointer)NULL);
   gtk_object_set_user_data(GTK_OBJECT(eventbox), tree_item);
   tree_item->pixmaps_box = eventbox;
@@ -441,12 +441,9 @@ gtk_tree_item_remove_pixmaps (GtkTreeItem *tree_item)
 
 static void
 gtk_tree_item_realize (GtkWidget *widget)
-{    
-  g_return_if_fail (GTK_IS_TREE_ITEM (widget));
+{
+  GTK_WIDGET_CLASS (parent_class)->realize (widget);
 
-  if (GTK_WIDGET_CLASS (parent_class)->realize)
-    (* GTK_WIDGET_CLASS (parent_class)->realize) (widget);
-  
   gdk_window_set_background (widget->window, 
 			     &widget->style->base[GTK_STATE_NORMAL]);
 
@@ -457,21 +454,15 @@ static void
 gtk_tree_item_size_request (GtkWidget      *widget,
 			    GtkRequisition *requisition)
 {
-  GtkBin *bin;
-  GtkTreeItem* item;
+  GtkBin *bin = GTK_BIN (widget);
+  GtkTreeItem *item = GTK_TREE_ITEM (widget);
   GtkRequisition child_requisition;
 
-  g_return_if_fail (GTK_IS_TREE_ITEM (widget));
-  g_return_if_fail (requisition != NULL);
-
-  bin = GTK_BIN (widget);
-  item = GTK_TREE_ITEM(widget);
-
   requisition->width = (GTK_CONTAINER (widget)->border_width +
 			widget->style->xthickness) * 2;
   requisition->height = GTK_CONTAINER (widget)->border_width * 2;
 
-  if (bin->child && GTK_WIDGET_VISIBLE (bin->child))
+  if (bin->child && gtk_widget_get_visible (bin->child))
     {
       GtkRequisition pix_requisition;
       
@@ -493,24 +484,18 @@ static void
 gtk_tree_item_size_allocate (GtkWidget     *widget,
 			     GtkAllocation *allocation)
 {
-  GtkBin *bin;
-  GtkTreeItem* item;
+  GtkBin *bin = GTK_BIN (widget);
+  GtkTreeItem *item = GTK_TREE_ITEM (widget);
   GtkAllocation child_allocation;
   gint border_width;
   int temp;
 
-  g_return_if_fail (GTK_IS_TREE_ITEM (widget));
-  g_return_if_fail (allocation != NULL);
-
   widget->allocation = *allocation;
-  if (GTK_WIDGET_REALIZED (widget))
+  if (gtk_widget_get_realized (widget))
     gdk_window_move_resize (widget->window,
 			    allocation->x, allocation->y,
 			    allocation->width, allocation->height);
 
-  bin = GTK_BIN (widget);
-  item = GTK_TREE_ITEM(widget);
-
   if (bin->child)
     {
       border_width = (GTK_CONTAINER (widget)->border_width +
@@ -612,16 +597,13 @@ gtk_tree_item_paint (GtkWidget    *widget,
   GdkRectangle child_area, item_area;
   GtkTreeItem* tree_item;
 
-  g_return_if_fail (GTK_IS_TREE_ITEM (widget));
-  g_return_if_fail (area != NULL);
-
   /* FIXME: We should honor tree->view_mode, here - I think
    * the desired effect is that when the mode is VIEW_ITEM,
    * only the subitem is drawn as selected, not the entire
    * line. (Like the way that the tree in Windows Explorer
    * works).
    */
-  if (GTK_WIDGET_DRAWABLE (widget))
+  if (gtk_widget_is_drawable (widget))
     {
       tree_item = GTK_TREE_ITEM(widget);
 
@@ -632,7 +614,7 @@ gtk_tree_item_paint (GtkWidget    *widget,
 	}
       else 
 	{
-	  if (!GTK_WIDGET_IS_SENSITIVE (widget)) 
+	  if (!gtk_widget_is_sensitive (widget))
 	    gtk_paint_flat_box(widget->style, widget->window,
 			       widget->state, GTK_SHADOW_NONE,
 			       area, widget, "treeitem",
@@ -658,13 +640,18 @@ gtk_tree_item_paint (GtkWidget    *widget,
 	  gtk_tree_item_draw_lines(widget);
 
 	  if (tree_item->pixmaps_box && 
-	      GTK_WIDGET_VISIBLE(tree_item->pixmaps_box) &&
+	      gtk_widget_get_visible(tree_item->pixmaps_box) &&
 	      gtk_widget_intersect (tree_item->pixmaps_box, area, &child_area))
-	    gtk_widget_draw (tree_item->pixmaps_box, &child_area);
+            {
+              gtk_widget_queue_draw_area (tree_item->pixmaps_box,
+                                          child_area.x, child_area.y,
+                                          child_area.width, child_area.height);
+              gdk_window_process_updates (tree_item->pixmaps_box->window, TRUE);
+            }
 	}
 
-      if (GTK_WIDGET_HAS_FOCUS (widget))
-	gtk_paint_focus (widget->style, widget->window, GTK_WIDGET_STATE (widget),
+      if (gtk_widget_has_focus (widget))
+	gtk_paint_focus (widget->style, widget->window, gtk_widget_get_state (widget),
 			 NULL, widget, "treeitem",
 			 0, 0,
 			 widget->allocation.width,
@@ -677,16 +664,12 @@ static gint
 gtk_tree_item_button_press (GtkWidget      *widget,
 			    GdkEventButton *event)
 {
-
-  g_return_val_if_fail (GTK_IS_TREE_ITEM (widget), FALSE);
-  g_return_val_if_fail (event != NULL, FALSE);
-
   if (event->type == GDK_BUTTON_PRESS
-	&& GTK_WIDGET_IS_SENSITIVE(widget)
-     	&& !GTK_WIDGET_HAS_FOCUS (widget))
-      gtk_widget_grab_focus (widget);
+      && gtk_widget_is_sensitive(widget)
+      && !gtk_widget_has_focus (widget))
+    gtk_widget_grab_focus (widget);
 
-  return (event->type == GDK_BUTTON_PRESS && GTK_WIDGET_IS_SENSITIVE(widget));
+  return (event->type == GDK_BUTTON_PRESS && gtk_widget_is_sensitive(widget));
 }
 
 static void
@@ -698,8 +681,8 @@ gtk_tree_item_expose_child (GtkWidget *child,
     GdkEventExpose *event;
   } *data = client_data;
 
-  if (GTK_WIDGET_DRAWABLE (child) &&
-      GTK_WIDGET_NO_WINDOW (child) &&
+  if (gtk_widget_is_drawable (child) &&
+      !gtk_widget_get_has_window (child) &&
       (child->window == data->event->window))
     {
       GdkEvent *child_event = gdk_event_new (GDK_EXPOSE);
@@ -725,11 +708,8 @@ gtk_tree_item_expose (GtkWidget      *widget,
     GtkWidget *container;
     GdkEventExpose *event;
   } data;
-  
-  g_return_val_if_fail (GTK_IS_TREE_ITEM (widget), FALSE);
-  g_return_val_if_fail (event != NULL, FALSE);
 
-  if (GTK_WIDGET_DRAWABLE (widget))
+  if (gtk_widget_is_drawable (widget))
     {
       gtk_tree_item_paint (widget, &event->area);
 
@@ -746,7 +726,7 @@ gtk_tree_item_expose (GtkWidget      *widget,
 
 static void
 gtk_real_tree_item_select (GtkItem *item)
-{    
+{
   GtkWidget *widget;
 
   g_return_if_fail (GTK_IS_TREE_ITEM (item));
@@ -781,7 +761,7 @@ gtk_real_tree_item_toggle (GtkItem *item)
 {
   g_return_if_fail (GTK_IS_TREE_ITEM (item));
 
-  if(!GTK_WIDGET_IS_SENSITIVE(item))
+  if(!gtk_widget_is_sensitive(GTK_WIDGET (item)))
     return;
 
   if (GTK_IS_TREE (GTK_WIDGET (item)->parent))
@@ -860,25 +840,21 @@ gtk_real_tree_item_collapse (GtkTreeItem *tree_item)
 static void
 gtk_tree_item_destroy (GtkObject *object)
 {
-  GtkTreeItem* item;
+  GtkTreeItem* item = GTK_TREE_ITEM(object);
   GtkWidget* child;
 
-  g_return_if_fail (GTK_IS_TREE_ITEM (object));
-
 #ifdef TREE_DEBUG
   g_message("+ gtk_tree_item_destroy [object %#x]\n", (int)object);
 #endif /* TREE_DEBUG */
 
-  item = GTK_TREE_ITEM(object);
-
   /* free sub tree if it exist */
   child = item->subtree;
   if (child)
     {
-      gtk_widget_ref (child);
+      g_object_ref (child);
       gtk_widget_unparent (child);
       gtk_widget_destroy (child);
-      gtk_widget_unref (child);
+      g_object_unref (child);
       item->subtree = NULL;
     }
   
@@ -886,10 +862,10 @@ gtk_tree_item_destroy (GtkObject *object)
   child = item->pixmaps_box;
   if (child)
     {
-      gtk_widget_ref (child);
+      g_object_ref (child);
       gtk_widget_unparent (child);
       gtk_widget_destroy (child);
-      gtk_widget_unref (child);
+      g_object_unref (child);
       item->pixmaps_box = NULL;
     }
   
@@ -898,7 +874,7 @@ gtk_tree_item_destroy (GtkObject *object)
   if (item->plus_pix_widget)
     {
       gtk_widget_destroy (item->plus_pix_widget);
-      gtk_widget_unref (item->plus_pix_widget);
+      g_object_unref (item->plus_pix_widget);
       item->plus_pix_widget = NULL;
     }
   
@@ -906,7 +882,7 @@ gtk_tree_item_destroy (GtkObject *object)
   if (item->minus_pix_widget)
     {
       gtk_widget_destroy (item->minus_pix_widget);
-      gtk_widget_unref (item->minus_pix_widget);
+      g_object_unref (item->minus_pix_widget);
       item->minus_pix_widget = NULL;
     }
   
@@ -938,7 +914,7 @@ gtk_tree_item_remove_subtree (GtkTreeItem* item)
       return;
     }
 
-  if (GTK_WIDGET_MAPPED (item->subtree))
+  if (gtk_widget_get_mapped (item->subtree))
     gtk_widget_unmap (item->subtree);
       
   gtk_widget_unparent (item->subtree);
@@ -964,24 +940,19 @@ gtk_tree_item_remove_subtree (GtkTreeItem* item)
 static void
 gtk_tree_item_map (GtkWidget *widget)
 {
-  GtkBin *bin;
-  GtkTreeItem* item;
+  GtkBin *bin = GTK_BIN (widget);
+  GtkTreeItem* item = GTK_TREE_ITEM(widget);
 
-  g_return_if_fail (GTK_IS_TREE_ITEM (widget));
-
-  bin = GTK_BIN (widget);
-  item = GTK_TREE_ITEM(widget);
-
-  GTK_WIDGET_SET_FLAGS (widget, GTK_MAPPED);
+  gtk_widget_set_mapped (widget, TRUE);
 
   if(item->pixmaps_box &&
-     GTK_WIDGET_VISIBLE (item->pixmaps_box) &&
-     !GTK_WIDGET_MAPPED (item->pixmaps_box))
+     gtk_widget_get_visible (item->pixmaps_box) &&
+     !gtk_widget_get_mapped (item->pixmaps_box))
     gtk_widget_map (item->pixmaps_box);
 
   if (bin->child &&
-      GTK_WIDGET_VISIBLE (bin->child) &&
-      !GTK_WIDGET_MAPPED (bin->child))
+      gtk_widget_get_visible (bin->child) &&
+      !gtk_widget_get_mapped (bin->child))
     gtk_widget_map (bin->child);
 
   gdk_window_show (widget->window);
@@ -990,25 +961,21 @@ gtk_tree_item_map (GtkWidget *widget)
 static void
 gtk_tree_item_unmap (GtkWidget *widget)
 {
-  GtkBin *bin;
-  GtkTreeItem* item;
+  GtkBin *bin = GTK_BIN (widget);
+  GtkTreeItem* item = GTK_TREE_ITEM(widget);
 
-  g_return_if_fail (GTK_IS_TREE_ITEM (widget));
-
-  GTK_WIDGET_UNSET_FLAGS (widget, GTK_MAPPED);
-  bin = GTK_BIN (widget);
-  item = GTK_TREE_ITEM(widget);
+  gtk_widget_set_mapped (widget, FALSE);
 
   gdk_window_hide (widget->window);
 
   if(item->pixmaps_box &&
-     GTK_WIDGET_VISIBLE (item->pixmaps_box) &&
-     GTK_WIDGET_MAPPED (item->pixmaps_box))
+     gtk_widget_get_visible (item->pixmaps_box) &&
+     gtk_widget_get_mapped (item->pixmaps_box))
     gtk_widget_unmap (bin->child);
 
   if (bin->child &&
-      GTK_WIDGET_VISIBLE (bin->child) &&
-      GTK_WIDGET_MAPPED (bin->child))
+      gtk_widget_get_visible (bin->child) &&
+      gtk_widget_get_mapped (bin->child))
     gtk_widget_unmap (bin->child);
 }
 
@@ -1018,14 +985,8 @@ gtk_tree_item_forall (GtkContainer *container,
 		      GtkCallback   callback,
 		      gpointer      callback_data)
 {
-  GtkBin *bin;
-  GtkTreeItem *tree_item;
-
-  g_return_if_fail (GTK_IS_TREE_ITEM (container));
-  g_return_if_fail (callback != NULL);
-
-  bin = GTK_BIN (container);
-  tree_item = GTK_TREE_ITEM (container);
+  GtkBin *bin = GTK_BIN (container);
+  GtkTreeItem *tree_item = GTK_TREE_ITEM (container);
 
   if (bin->child)
     (* callback) (bin->child, callback_data);
